---
jupytext:
  cell_metadata_filter: -all
  formats: md:myst
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.13
    jupytext_version: 1.11.5
kernelspec:
  display_name: Python 3
  language: python
  name: python3
---

# Calidad del Aire 2023: Area Metropolitana de Bucaramanga

## Concentración Promedio anual de PM2.5
 > A continuación se reporta la concentración promedio anual de material particulado menor a 2.5 micras (PM25) para las estaciones de la Red de Monitoreo Ambiental RACIMO-Móncora.  Este valor esta dado  por la suma de las concentraciones diarias de PM25 registrados, divididas por el número de concentraciones diarias registrados en el año. 

```{code-cell} ipython3
:tags: [remove-input, full-width]

import pandas as pd
import numpy as np
import os
import folium
from folium.plugins import BeautifyIcon

Estaciones = [('E2_00023','Grupo Halley',7.1393716,-73.1210968),           
            ('mE1_00004','Inst. Tecnologico',7.1381572,-73.1180935),
            ('mE1_00005','Col. Santander',7.1385332,-73.121327),
            ('mE1_00007','Col. Normal',7.1277056,-73.116534),
            ('mE1_00006','I.E. Pilar',7.1087178, -73.1217347),
            ('mE1_00008','FundeUis',7.05756, -73.0912),
            ('mE2_00000','I.E. Piloto Simón Bolivar',7.1364570, -73.1279554),
            ('mE2_00001','I.E. Luis Carlos Galán',7.0933820, -73.1422931),
            ('mE1_00012','I.E. Café Madrid',7.1631654, -73.14033300)
             ]

Nest=len(Estaciones)
data=[[] for i in range(Nest)]

for i in range(1,Nest):
    est = Estaciones[i]
    file = "/".join(["./data2023",est[0]])
    file = ".".join([file,"csv"])

    if os.path.exists(file):
        data[i] = pd.read_csv(file)
        data[i].index = pd.DatetimeIndex(data[i].ts)
        del data[i]["ts"]

for i in range(1,Nest):
    est = Estaciones[i]
    data[i]['pm25_r'] = data[i]['pm25'].rolling(window = 100,min_periods=20).mean() 

meanPm25=np.zeros(Nest)
for i in range(1,Nest):
    meanPm25[i]= data[i]["pm25"].mean() 

# Calcular centro entre estaciones extremas
latitudes = np.array(Estaciones)[:,2].astype('float64')
latitud = (np.max(latitudes)+np.min(latitudes))/2
longitudes = np.array(Estaciones)[:,3].astype('float64')
longitud = (np.max(longitudes)+np.min(longitudes))/2

z = int(13-np.log2(10*(np.max(latitudes)-np.min(latitudes)))) # Zoom inicial en el mapa


shift1 = 0.001 # Trasladar estaciones cercanas

latitudes[0] += 4*shift1
longitudes[1] += shift1
longitudes[2] -= 2*shift1
latitudes[-2] -=2*shift1

#shift = 0.00266
shift2 = 0.005 # Desplazar marcadores de ubicación

ubicaciones = []
for i in range(len(latitudes)):
    ubicaciones.append([latitudes[i],longitudes[i]])

ubicaciones[0][0] += shift2
ubicaciones[1][1] += shift2
ubicaciones[2][0] += 0.65*shift2
ubicaciones[2][1] -= 0.9*shift2
ubicaciones[3][0] -= shift2
ubicaciones[4][0] -= shift2
ubicaciones[5][0] += shift2
ubicaciones[6][0] -= shift2
ubicaciones[7][0] += shift2
ubicaciones[8][0] -= shift2

# Crear el mapa de Bucaramanga con el estilo "CartoDB Positron"
bucaramanga_map = folium.Map(location=[latitud, longitud], 
                              zoom_start=z, tiles='CartoDB Positron',width=677,height=660, zoom_control=False)


def get_color(number):
    if number==0:
        return "#808080"  # Gris
    elif 0 < number <= 12:
        return '#00FF2E'  # Verde
    elif 13 <= number <= 37:
        return '#FFE000'  # Amarillo
    elif 38 <= number <= 55:
        return '#FF6100'  # Naranja
    elif 56 <= number:
        return '#FF0000'  # Rojo

    
for i in range(1,len(meanPm25)):
        
        if meanPm25[i] >= 0.0: # Valor crítico para alerta. Es 0 si se quieren mostrar todas las estaciones
            
            if meanPm25[i]==0.0:
                valor = 'X'
            else:
                valor = np.round(meanPm25[i],1)
            # Crear el ícono personalizado con un número
            icon_number = BeautifyIcon(
            border_color=get_color(meanPm25[i]),
            text_color='#000000',#get_color(pm25[i]),
            number=valor,
            background_color='transparent', # Fondo transparente para que se vean estaciones cercanas entre sí
            icon_size=(40, 40),  # Tamaño del ícono en píxeles
            inner_icon_style='line-height:25px; font-size: 12px;',  # Ajusta el tamaño de la fuente aquí
            spin=True,
            border_width=2,
            )

            # Agregar marcador al mapa
            folium.Marker(
                [latitudes[i], longitudes[i]],
                popup=Estaciones[i][1],
                icon=icon_number
            ).add_to(bucaramanga_map)
            
    
ne = [7.164165408989283, -73.14033300778485]
sw = [7.0530,-73.0979968]

#7.1630887,-73.1403283

bucaramanga_map.fit_bounds([sw, ne]) 


display(bucaramanga_map)

 

```

## Comportamiento mensual de la concentración de PM25

 > La concentración de PM25 alcanzó los  valores más altos en el meses de marzo, mayo y diciembre, mientras que las concentraciones promedio más bajas se registraron en los meses de junio y julio. Particulamente, la zona donde se ubica el Colegio Luis Carlos Galán registra los valores más altos de concentración de PM25 de la Red de Monitoreo Ambiental RACIMO-Móncora.

```{code-cell} ipython3
:tags: [remove-input, full-width]

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.dates as mdates

import plotly.express as px
import plotly.graph_objects as go

Estaciones = [('E2_00023','Grupo Halley',7.1393716,-73.1210968),           
            ('mE1_00004','I. Tecnologico',7.1381572,-73.1180935),
            ('mE1_00005','C. Santander',7.1385332,-73.121327),
            ('mE1_00007','C. Normal',7.1277056,-73.116534),
            ('mE1_00006','I.E. Pilar',7.1087178, -73.1217347),
            ('mE1_00008','FundeUis',7.05756, -73.0912),
            ('mE2_00000','I.E. Piloto',7.1364570, -73.1279554),
            ('mE2_00001','I.E. L. C. Galán',7.0933820, -73.1422931),
            ('mE1_00012','I.E. Café Madrid',7.1631654, -73.14033300)
             ]

fecha_inicio = "2023-02-24 00:00:00"
fecha_fin = "2023-12-20 00:00:00"

Nest=len(Estaciones)
data=[[] for i in range(Nest)]

for i in range(1,Nest):
    est = Estaciones[i]
    file = "/".join(["./data2023",est[0]])
    file = ".".join([file,"csv"])

    if os.path.exists(file):
        data[i] = pd.read_csv(file)
        data[i].index = pd.DatetimeIndex(data[i].ts)
        del data[i]["ts"]

dat = [[] for i in range(Nest)]
for i in range(1,Nest):
    est = Estaciones[i]
    data[i]['pm25_r'] = data[i]['pm25'].rolling(window = 100,min_periods=20).mean() 
    data[i]['mes'] = data[i].index.month.values
    data[i]['hour'] = data[i].index.hour

    #Establecer frecuenica
    dat[i] = data[i].resample('1D').mean()
    
    dat[i]['Estacion'] = est[1]
    dat[i]['id_est'] = int(i)
    data[i]['Estacion'] = est[1]
    data[i]['id_est'] = int(i)



fig = plt.subplots(figsize=(20,20))

col = 2
row = int( (Nest-1)/col )
i=0; j=0
for ii in range(1,Nest):
    ax = plt.subplot2grid((row,col), (j,i) ) 
    # Crear gráfico
    data[ii].pm25.plot(ax=ax,label=' ' , marker='o',ls="", markersize=0.5, alpha=0.2)
    dat[ii].pm25_r.plot(ax=ax,label=' Promedio PM 25 ', ls="-", color="navy")

    ax.axhline(y=37, color='r', linestyle='--', label='Nivel Máximo Permisible 24 horas (37 $\mu g /m^3$)')
    ax.axhline(y=12, color='orange', linestyle='--', label='Nivel Aceptable Permisible 24 horas (12 $\mu g /m^3$)')

    Ndat= dat[ii].shape[0]
    ax.text(dat[ii].index[int(0.5*Ndat)], 50, Estaciones[ii][1], ha="center", va="bottom", fontsize=25, fontweight="bold")
    
    if i==0:
        ax.set_ylabel("PM 25 $[\, \mu g / m^3\, ]$", fontsize=25, fontweight="bold")
        ax.tick_params(which='major', pad=1, length=8, labelsize=15, direction="inout", width=1.5)
       

        if j==0:
            ax.legend(loc="upper left")
    else:
        ax.axes.yaxis.set_visible(False)


    if j==(row-1):
        ax.xaxis.set_major_formatter(mdates.DateFormatter('%b'))
        plt.xticks(rotation=0)
        ax.set_xlabel("")
        #ax.xaxis.set_major_locator(mdates.DayLocator(interval=32))
        ax.tick_params(which='minor', labelsize=18, length=8)
         
    else:
        ax.axes.xaxis.set_visible(False)


    ax.set_ylim(-2., 75)
    ax.set_xlim(fecha_inicio, fecha_fin)
    
    i+=1
    if i > (col-1):
        i=0
        j+=1


plt.subplots_adjust(left=0.06, bottom=0.1, right=0.99, top=0.99,  wspace=0.01, hspace=0)

plt.show()



```

## Comportamiento diario de la concentración de PM25

> En todas las estaciones de la Red de Monitoreo Ambiental RACIMO-Móncora se registran  picos en la concentración de PM25 entre las 11:00 y 13:00 horas del día. 

```{code-cell} ipython3
:tags: [remove-input, full-width]

import pandas as pd
import numpy as np
import plotly.express as px
import plotly.graph_objects as go
import matplotlib.pyplot as plt
import matplotlib.dates as mdates
from matplotlib.colors import LinearSegmentedColormap
import seaborn as sns

Estaciones = [('E2_00023','Grupo Halley',7.1393716,-73.1210968),           
            ('mE1_00004','I. Tecnologico',7.1381572,-73.1180935),
            ('mE1_00005','C. Santander',7.1385332,-73.121327),
            ('mE1_00007','C. Normal',7.1277056,-73.116534),
            ('mE1_00006','I.E. Pilar',7.1087178, -73.1217347),
            ('mE1_00008','FundeUis',7.05756, -73.0912),
            ('mE2_00000','I.E. Piloto ',7.1364570, -73.1279554),
            ('mE2_00001','I.E. L. C. Galán',7.0933820, -73.1422931),
            ('mE1_00012','I.E. Café Madrid',7.1631654, -73.14033300)
             ]


Nest=len(Estaciones)
data=[[] for i in range(Nest)]

for i in range(1,Nest):
    est = Estaciones[i]
    file = "/".join(["./data2023",est[0]])
    file = ".".join([file,"csv"])

    if os.path.exists(file):
        data[i] = pd.read_csv(file)
        data[i].index = pd.DatetimeIndex(data[i].ts)
        del data[i]["ts"]

dat = [[] for i in range(Nest)]
for i in range(1,Nest):
    est = Estaciones[i]
    data[i]['pm25_r'] = data[i]['pm25'].rolling(window = 100,min_periods=20).mean() 
    data[i]['mes'] = data[i].index.month.values
    data[i]['hour'] = data[i].index.hour

i_ini=1
for i in range(i_ini,Nest):
   
    hourly_1 = data[i].pm25.groupby(data[i].hour).mean()
    
    if i==i_ini:
        hr_0 = (hourly_1).to_frame()
        hr_0.columns = [Estaciones[i][1]]
    else:
         hr_1 = (hourly_1).to_frame()
         hr_1.columns = [Estaciones[i][1]]
         hr_0 = hr_0.join(hr_1)

df_all_transposed = hr_0.transpose()

cvals  = [0,13, 38, 56,]
colors = ["green",  'yellow', 'orange', "red", ]

norm=plt.Normalize(min(cvals),max(cvals))
tuples = list(zip(map(norm,cvals), colors))
cmap = LinearSegmentedColormap.from_list('name', tuples)

sns.set(font_scale=1.4)

plt.figure(figsize=(15,10), facecolor='w', edgecolor='k')
sns.heatmap(df_all_transposed,cmap=cmap,square=True, linewidths=2, vmin=0, vmax=56,
           cbar_kws={'fraction' : 0.01, 'pad': 0.02,'label': '$\\mathrm{PM}_{2.5}\,  [\,\mu g\, \, \\mathrm{cm}^{-3}\,]$'},
            annot = True,
            annot_kws = {'size': 8})
plt.yticks(rotation=0) 
plt.xlabel('Hora')


plt.show()

```
